Struct linfa_elasticnet::ElasticNet [−][src]
Elastic Net model
This struct contains the parameters of a fitted elastic net model. This includes the seperating hyperplane, (optionally) intercept, duality gaps and the number of step needed in the computation.
Implementations
impl<F: Float> ElasticNet<F>[src]
View the fitted parameters and make predictions with a fitted elastic net model
pub fn parameters(&self) -> &Array1<F>[src]
Get the fitted parameters
pub fn intercept(&self) -> F[src]
Get the fitted intercept, 0. if no intercept was fitted
pub fn n_steps(&self) -> u32[src]
Get the number of steps taken in optimization algorithm
pub fn duality_gap(&self) -> F[src]
Get the duality gap at the end of the optimization algorithm
pub fn z_score(&self) -> Result<Array1<F>>[src]
Calculate the Z score
pub fn confidence_95th(&self) -> Result<Array1<(F, F)>>[src]
Calculate the confidence level
impl<F: Float> ElasticNet<F>[src]
pub fn params() -> ElasticNetParams<F>[src]
Create a default elastic net model
By default, an intercept will be fitted. To disable fitting an
intercept, call .with_intercept(false) before calling .fit().
To additionally normalize the feature matrix before fitting, call
fit_intercept_and_normalize() before calling fit(). The feature
matrix will not be normalized by default.
pub fn ridge() -> ElasticNetParams<F>[src]
Create a ridge model
pub fn lasso() -> ElasticNetParams<F>[src]
Create a lasso model